Sign inSign up

restohq/resto-full

By restohq

•Updated about 2 years ago

the full container of resto - `a CLI app can send pretty HTTP & API requests with TUI. `

Image
1

901

restohq/resto-full repository overview

⁠Resto

a CLI app can send pretty HTTP & API requests with TUI.

⁠Installation

⁠Using script
  • Shell
curl -fsSL https://git.io/resto | bash
  • PowerShell
iwr -useb https://git.io/resto-win | iex

then restart your powershell

⁠Go package manager
go install github.com/abdfnx/resto@latest
⁠GitHub CLI
gh extension install abdfnx/gh-resto

⁠Usage

  • Open Resto UI

    resto
    
  • Send a request to a URL

    resto get https://api.github.com
    
  • Send a request to a URL and use resto editor

    resto post https://localhost:3000/v1/login --content-type json --editor
    
  • Read Body from stdin

    cat schema.graphql | resto post https://api.spacex.land/graphql --content-type graphql --body-stdin
    
  • Use Authentecation with Basic Auth or Bearer Token

    # Bearer Token
    resto delete https://api.secman.dev/api/logins/13 --content-type json --token TOKEN
    
    # Basic Auth
    resto delete https://api.secman.dev/api/logins/13 --content-type json --username USERNAME --password PASSWORD
    
  • Save response to a file

    resto get http://localhost:3333/api/v1/hello --save response.json
    
⁠Flags
  1. GET & HEAD flags
-H, --headers           Just show the response headers
-j, --just-body         Just show the response body
-p, --password string   The password to use for basic authentication
-s, --save string       Save the response body to a file
-t, --token string      The bearer token to use for authentication
-u, --username string   The username to use for basic authentication
  1. POST, PUT, PATCH, DELETE flags
-b, --body string           The body of the request
-i, --body-stdin            Read the body from stdin
-c, --content-type string   The content type of the body
-e, --editor                Open the editor to edit the body
-H, --headers               Just show the response headers
-j, --just-body             Just show the response body
-p, --password string       The password to use for basic authentication
-s, --save string           Save the response to a file
-t, --token string          The bearer token to use for authentication
-u, --username string       The username to use for basic authentication

⁠Documentation

Refer to resto website⁠ for the documentation. Or you can check out the Wiki⁠.

Tag summary

Content type

Image

Digest

sha256:f0fe27dbf…

Size

162.4 MB

Last updated

about 2 years ago

docker pull restohq/resto-full